@@ -7,12 +7,10 @@ COMPUTER_NAME = socket.gethostname()
 
 def got_key() -> bool:
     """
-    check if current user has the registry key subsearch for the context menu
+    Check if current user has the registry key subsearch for the context menu
 
-    Returns
-    -------
-    bool
-        returns True or False
+    Returns:
+        bool: True if key exists, False if key does not exist
     """
     sub_key = r"Software\Classes\*\shell\0.SubSearch\command"
     try:
@@ -25,12 +23,10 @@ def got_key() -> bool:
 
 def check_is_exe() -> bool:
     """
-    check if the current user is running subsearch from the executable
+    Check if the current user is running subsearch from the executable
 
-    Returns
-    -------
-    bool
-        returns True or False
+    Returns:
+        bool: True if subsearch is running as executable, False if subsearch is not running as executable
     """
 
     if sys.argv[0].endswith("SubSearch.exe"):
